Routes Documentation — Routes v1.11 documentation

Routes

### Navigation

- index
- modules |
- next |
- Routes home |
- Documentation»

# Routes Documentation

- Routes Manual
  - Introduction
  - Setting up routes
  - Generation
  - Unicode
  - RESTful services
  - Redirect routes
  - Introspection
  - Other
  - Backward compatibility

- Glossary
- Porting Routes to a WSGI Web Framework

# Indices and tables

- Index
- Module Index
- Search Page
- Glossary

## Module Listing

- `routes` – Routes module
  - Module Contents

### Navigation

- index
- modules |
- next |
- Routes home |
- Documentation»